@@ -61,7 +61,7 @@ class BubblePoint:
     (355, 109755.4531986941, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.343, 0.657]))
     >>> # Solve bubble point at constant pressure
     >>> BP(z=molar_composition, P=101325)
-    BubblePointValues(T=352.9503026994659, P=101325, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.342 0.658])
+    BubblePointValues(T=352.9503026992783, P=101325, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.342 0.658])
     
     """
     __slots__ = ('chemicals', 'IDs', 'gamma', 'phi', 'pcf',
@@ -116,7 +116,7 @@ class BubblePoint:
         Tmax = self.Tmax
         T = flx.IQ_interpolation(f, Tmin, Tmax,
                                  f(Tmin, *args), f(Tmax, *args),
-                                 None, 1e-6, 5e-9, args)
+                                 None, 1e-6, 5e-9, args, checkbounds=False)
         return T
     
     def _P_ideal(self, z_Psat_gamma_pcf):
@@ -159,7 +159,7 @@ class BubblePoint:
         >>> tmo.settings.set_thermo(chemicals)
         >>> BP = tmo.equilibrium.BubblePoint(chemicals)
         >>> BP.solve_Ty(z=np.array([0.6, 0.4]), P=101325)
-        (353.75434459554066, array([0.381, 0.619]))
+        (353.75434459553395, array([0.381, 0.619]))
         
         """
         self.P = P
@@ -170,12 +170,14 @@ class BubblePoint:
         T_guess = self.T or self._T_ideal(z_over_P) 
         try:
             T = flx.aitken_secant(f, T_guess, T_guess+0.1,
-                                  1e-6, 5e-9, args)
+                                  1e-6, 5e-9, args,
+                                  checkroot=False)
         except (InfeasibleRegion, DomainError):
             Tmin = self.Tmin; Tmax = self.Tmax
             T = flx.IQ_interpolation(f, Tmin, Tmax,
                                      f(Tmin, *args), f(Tmax, *args),
-                                     T_guess, 1e-6, 5e-9, args)
+                                     T_guess, 1e-6, 5e-9, args, 
+                                     checkroot=False, checkbounds=False)
         self.y = fn.normalize(self.y)
         return T, self.y.copy()
     
@@ -216,12 +218,14 @@ class BubblePoint:
         args = (T, z_Psat_gamma_pcf)
         P_guess = self.P or self._P_ideal(z_Psat_gamma_pcf)
         try:
-            P = flx.aitken_secant(f, P_guess, P_guess-10, 1e-3, 1e-9, args)
+            P = flx.aitken_secant(f, P_guess, P_guess-10, 1e-3, 1e-9,
+                                  args, checkroot=False)
         except (InfeasibleRegion, DomainError):
             Pmin = self.Pmin; Pmax = self.Pmax
             P = flx.IQ_interpolation(f, Pmin, Pmax,
                                      f(Pmin, *args), f(Pmax, *args),
-                                     P_guess, 1e-3, 5e-9, args)
+                                     P_guess, 1e-3, 5e-9, args,
+                                     checkroot=False)
         self.y = fn.normalize(self.y)
         return P, self.y.copy()
     
