@@ -56,13 +56,13 @@ class DewPoint:
     >>> molar_composition = (0.5, 0.5)
     >>> dp = DP(z=molar_composition, T=355)
     >>> dp
-    DewPointValues(T=355, P=91970.14968399623, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.851 0.149])
+    DewPointValues(T=355, P=91970.14968402045, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.851 0.149])
     >>> # Note that the result is a DewPointValues object which contain all results as attibutes
     >>> (dp.T, dp.P, dp.IDs, dp.z, dp.x)
-    (355, 91970.14968399623, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.851, 0.149]))
+    (355, 91970.14968402045, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.851, 0.149]))
     >>> # Solve for dew point at constant pressure
     >>> DP(z=molar_composition, P=2*101324)
-    DewPointValues(T=376.2616600249248, P=202648, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.832 0.168])
+    DewPointValues(T=376.26166000908694, P=202648, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.832 0.168])
 
     """
     __slots__ = ('chemicals', 'phi', 'gamma', 'IDs',
@@ -120,7 +120,8 @@ class DewPoint:
         args = (zP,)
         T = flx.IQ_interpolation(f, Tmin, Tmax,
                                  f(Tmin, *args), f(Tmax, *args),
-                                 None, 1e-6, 5e-9, args)
+                                 None, 1e-6, 5e-9, args,
+                                 checkroot=False, checkbounds=False)
         return T
     
     def _P_ideal(self, z_over_Psats):
@@ -163,7 +164,7 @@ class DewPoint:
         >>> tmo.settings.set_thermo(chemicals)
         >>> DP = tmo.equilibrium.DewPoint(chemicals)
         >>> DP.solve_Tx(z=np.array([0.5, 0.5]), P=101325)
-        (357.45184743325336, array([0.849, 0.151]))
+        (357.45184743326394, array([0.849, 0.151]))
         """
         f = self._T_error
         z_norm = z/z.sum()
@@ -173,13 +174,15 @@ class DewPoint:
         T_guess = self.T or self._T_ideal(zP) 
         try:
             T = flx.aitken_secant(f, T_guess, T_guess+0.1,
-                                  1e-6, 5e-9, args)
+                                  1e-6, 5e-9, args,
+                                  checkroot=False)
         except (InfeasibleRegion, DomainError):
             Tmin = self.Tmin
             Tmax = self.Tmax
             T = flx.IQ_interpolation(f, Tmin, Tmax,
                                      f(Tmin, *args), f(Tmax, *args),
-                                     T_guess, 1e-6, 5e-9, args)
+                                     T_guess, 1e-6, 5e-9, args,
+                                     checkroot=False, checkbounds=False)
         self.x = fn.normalize(self.x)
         return T, self.x.copy()
     
@@ -209,7 +212,7 @@ class DewPoint:
         >>> tmo.settings.set_thermo(chemicals)
         >>> DP = tmo.equilibrium.DewPoint(chemicals)
         >>> DP.solve_Px(z=np.array([0.5, 0.5]), T=352.28)
-        (82444.29876047897, array([0.853, 0.147]))
+        (82444.29876053802, array([0.853, 0.147]))
  
        """
         z_norm = z/z.sum()
@@ -220,13 +223,15 @@ class DewPoint:
         f = self._P_error
         P_guess = self.P or self._P_ideal(z_over_Psats)
         try:
-            P = flx.aitken_secant(f, P_guess, P_guess-10, 1e-3, 1e-9, args)
+            P = flx.aitken_secant(f, P_guess, P_guess-10, 1e-3, 1e-9, args,
+                                  checkroot=False)
         except (InfeasibleRegion, DomainError):
             Pmin = self.Pmin
             Pmax = self.Pmax
             P = flx.IQ_interpolation(f, Pmin, Pmax, 
                                      f(Pmin, *args), f(Pmax, *args),
-                                     P_guess, 1e-3, 5e-9, args)
+                                     P_guess, 1e-3, 5e-9, args,
+                                     checkroot=False, checkbounds=False)
         self.x = fn.normalize(self.x)
         return P, self.x.copy()
     
