@@ -1,4 +1,18 @@
 # -*- coding: utf-8 -*-
+# BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
+# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# 
+# A significant portion of this module originates from:
+# Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+# Copyright (C) 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+# 
+# This module is under a dual license:
+# 1. The UIUC open-source license. See 
+# github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
+# for license details.
+# 
+# 2. The MIT open-source license. See
+# https://github.com/CalebBell/thermo/blob/master/LICENSE.txt for details.
 """
 This module includes elemental data taken from [1]_ and [2]_, and 
 functions to calculate molecular properties from elemental data.
@@ -283,7 +297,7 @@ def compute_mass_fractions(atoms, MW=None):
         if i in periodic_table:
             mfracs[i] = periodic_table[i].MW*atoms[i]/MW
         else:
-            raise Exception('Molecule includes unknown atoms')
+            raise ValueError('invalid atom {i}')
     return mfracs
 
 
@@ -514,7 +528,7 @@ def parse_nested_formula(formula, check=True):
     # The set of letters in the tokens should match the set of letters
     if check:
         token_letters = set([j for i in tokens for j in i if j in letter_set])
-        formula_letters = set(i for i in formula if i in letter_set)
+        formula_letters = set([i for i in formula if i in letter_set])
         if formula_letters != token_letters:
             raise Exception('Input may not be a formula; extra letters were detected')
     
